.. bilby NR documentation master file, created by
   sphinx-quickstart on Tue Feb 17 12:45:27 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

bilby NR documentation
======================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   citing

